.. _installation:

Requirements
=============

- python >= 3.6
- Flask >= 0.8


Installation
=============

**Flask-Collect-Invenio** should be installed using pip: ::

    pip install Flask-Collect-Invenio
